Package: ie2miscdata
Title: Irucka Embry's Miscellaneous USGS Data Collection
Version: 1.0.4
Author: Irucka Embry [aut, cre]
Maintainer: Irucka Embry <iembry@ecoccs.com>
Depends: R (>= 3.5.0)
Suggests: install.load, data.table (>= 1.10.2), USA.state.boundaries
        (>= 1.0.1), spatstat.geom, ggplot2 (>= 3.3.4), stringi, mgsub,
        knitr, rmarkdown, reader, sf, rvest, spelling, lubridate, gotop
Description: A collection of Irucka Embry's miscellaneous USGS data sets (USGS
    Parameter codes with fixed values, USGS global time zone codes, and US Air
    Force Global Engineering Weather Data). Irucka created these data sets
    while a Cherokee Nation Technology Solutions (CNTS) United States
    Geological Survey (USGS) Contractor and/or USGS employee.
URL: https://gitlab.com/iembry/ie2miscdata
BugReports: https://gitlab.com/iembry/ie2miscdata/-/issues
License: CC0
Copyright: This software is in the public domain because it contains
        materials that originally came from the United States
        Geological Survey, an agency of the United States Department of
        Interior. For more information, see the official USGS copyright
        policy at
        <https://www.usgs.gov/information-policies-and-instructions/copyrights-and-credits#copyright>
Language: en-US
Encoding: UTF-8
LazyData: true
LazyDataCompression: xz
VignetteBuilder: knitr
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2023-08-20 22:04:40 UTC; xbyri
Repository: CRAN
Date/Publication: 2023-08-20 22:52:33 UTC
Built: R 4.6.0; ; 2026-04-25 19:39:09 UTC; unix
